summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/plugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/plugin.h')
-rw-r--r--umbrello/umbrello/plugin.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/plugin.h b/umbrello/umbrello/plugin.h
index e566c5cc..1fa4d7f4 100644
--- a/umbrello/umbrello/plugin.h
+++ b/umbrello/umbrello/plugin.h
@@ -81,7 +81,7 @@ class PluginLoader;
* only available within the scope of the shared library, the configuration
* records must be set in the constructor of the derived plugin class. However,
* because the construction name is passed to this constructor (as are the
* tqparent object and args), we can simply capture the name when the object
* is constructed.
*/
class Plugin :
@@ -113,7 +113,7 @@ public:
protected:
/** Construct a plugin */
- Plugin(TQObject *tqparent, const char *name, const TQStringList &args);
+ Plugin(TQObject *parent, const char *name, const TQStringList &args);
/** Can be reimplemented to define plugin specific startup behavior */
virtual bool onInit();
@@ -81,7 +81,7 @@ class PluginLoader;
* records must be set in the constructor of the derived plugin class. However,
* because the construction name is passed to this constructor (as are the
- * tqparent object and args), we can simply capture the name when the object
+ * parent object and args), we can simply capture the name when the object
* is constructed.
*/